package cn.com.qmth.examcloud.core.questions.api.controller;

import javax.servlet.http.HttpServletRequest;

import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.commons.base.exception.StatusException;
import cn.com.qmth.examcloud.commons.web.security.bean.User;
import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.questions.api.request.GetDefaultQuesionReq;
import cn.com.qmth.examcloud.core.questions.api.request.GetDefaultQuesionsReq;
import cn.com.qmth.examcloud.core.questions.service.QuestionProviderService;
import cn.com.qmth.examcloud.question.core.question.DefaultQuestion;

/**
 * @author 		weiwenhai
 * @date 		20180.9.10
 * @company		qmth
 * @description	controller
 * @code		013
 */
@RestController
@RequestMapping("${api_cqb}/default_question")
public class DefaultQuesionController extends ControllerSupport {

	@Autowired
	QuestionProviderService questionProviderService;
	
	@ApiOperation(value = "外部接口保存单个试题", notes = "外部接口保存单个试题")
    @PostMapping("/save")
	public ResponseEntity<Object> save(HttpServletRequest request, @RequestBody GetDefaultQuesionReq req) {
		User user = getAccessUser();
		if(user == null){
			throw new StatusException("Q-013041", "用户不存在！");
		}
		DefaultQuestion defaultQuestion = req.getDefaultQuestion();
		if(defaultQuestion.getRootOrgId() == null){
			throw new StatusException("Q-013045", "rootOrgId is null");
		}
		String id = questionProviderService.save(defaultQuestion);
		return new ResponseEntity<Object>(id,HttpStatus.OK);
	}
	
	@ApiOperation(value = "修改试题")
	@PutMapping("/update")
	public ResponseEntity<Object> update(HttpServletRequest request, @RequestBody GetDefaultQuesionReq req) {
		User user = getAccessUser();
		if(user == null){
			throw new StatusException("Q-013057", "用户不存在！");
		}
		DefaultQuestion defaultQuestion = req.getDefaultQuestion();
		if(defaultQuestion.getRootOrgId() == null){
			throw new StatusException("Q-013061", "rootOrgId is null");
		}
		String id = questionProviderService.save(defaultQuestion);
		return new ResponseEntity<Object>(id,HttpStatus.OK);
	}
	
	@ApiOperation(value = "查询试题")
	@PostMapping("/find")
	public ResponseEntity<Object> find(HttpServletRequest request, @RequestBody GetDefaultQuesionsReq req) {
		User user = getAccessUser();
		if(user == null){
			throw new StatusException("Q-013075", "用户不存在！");
		}
		Long rootOrgId = req.getRootOrgId();
		if(rootOrgId == null){
			throw new StatusException("Q-011079", "rootOrgId is null");
		}
		Page<DefaultQuestion> defaultQuestions = questionProviderService.findQustions(rootOrgId,req.getProperties(),req.getCurPage(),req.getPageSize());
		return new ResponseEntity<Object>(defaultQuestions,HttpStatus.OK);
	}
}
